@@ -81,8 +81,7 @@ resource_cmds = ["import resource",
                  "resource.setrlimit(resource.RLIMIT_NPROC, (max(cur_proc, target_proc), max_proc))",
                  "cur_hdls, max_hdls = resource.getrlimit(resource.RLIMIT_NOFILE)",
                  "target_hdls = min(max_hdls, %s)" % target_procs,
-                 "resource.setrlimit(resource.RLIMIT_NOFILE, (max(cur_hdls, target_hdls), max_hdls))",
-                 "print(resource.getrlimit(resource.RLIMIT_NPROC), resource.getrlimit(resource.RLIMIT_NOFILE))"]
+                 "resource.setrlimit(resource.RLIMIT_NOFILE, (max(cur_hdls, target_hdls), max_hdls))"]
 engine_cmd_argv = launcher.ipengine_cmd_argv[:2] + \
                   ["; ".join(resource_cmds + launcher.ipengine_cmd_argv[2].split("; "))]
 cluster_cmd_argv = launcher.ipcluster_cmd_argv[:2] + \
@@ -181,11 +180,14 @@ class BcbioSGEControllerLauncher(launcher.SGEControllerLauncher):
 def _find_parallel_environment(queue):
     """Find an SGE/OGE parallel environment for running multicore jobs in specified queue.
     """
+    base_queue = os.path.splitext(queue)[0]
+    queue = base_queue + ".q"
+
     for name in subprocess.check_output(["qconf", "-spl"]).strip().split():
         if name:
             for line in subprocess.check_output(["qconf", "-sp", name]).split("\n"):
                 if _has_parallel_environment(line):
-                    if _queue_can_access_pe(name, queue):
+                    if (_queue_can_access_pe(name, queue) or _queue_can_access_pe(name, base_queue)):
                         return name
     raise ValueError("Could not find an SGE environment configured for parallel execution. " \
                      "See %s for SGE setup instructions." %
@@ -215,9 +217,10 @@ def _parseSGEConf(data):
 def _queue_can_access_pe(pe_name, queue):
     """Check if a queue has access to a specific parallel environment, using qconf.
     """
-    if not queue.endswith(".q"):
-        queue = "%s.q" % queue
-    queue_config = _parseSGEConf(subprocess.check_output(["qconf", "-sq", queue]))
+    try:
+        queue_config = _parseSGEConf(subprocess.check_output(["qconf", "-sq", queue]))
+    except:
+        return False
     for test_pe_name in queue_config["pe_list"].split():
         test_pe_name = test_pe_name.split(",")[0].strip()
         if test_pe_name == pe_name:
